/*
 *
 *  $Id: countdownmessage.h 4719 2012-02-17 13:32:45Z carlos $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
 *  See License.txt for details
 *
 *
 */
#pragma once

#include <wx/timer.h>
#include "countdownmessagebase.h"

namespace GNC {
	namespace GUI {
		class CountdownMessage: public CountdownMessageBase, public wxTimer
		{
		public:
			CountdownMessage(wxWindow* pParent);
			~CountdownMessage();
			virtual bool Show(bool show=true);
		protected:
			virtual void OnCancel(wxCommandEvent &event);
			virtual void OnCloseButton(wxCommandEvent &event);
			virtual void OnClose(wxCloseEvent &event);
			virtual void Notify();
			int m_last;
		};
	}
}
